/* Copyright (c) 2017 Asustor Inc. All rights reserved. */
/**
 * @class AS.ARC.apps.radiusserver.log.log
 * @extends AS.ARC.apps.radiusserver.page
 * @author JerryJiang 2017-06-23
 */
Ext.define('AS.ARC.apps.radiusserver.log.log', {
	extend: 'AS.ARC.apps.radiusserver.page',

	pageTag: 'log',
	apiUrl: AS.ARC.util.getUserAppsPath() + 'radiusserver/radiusserver.cgi',

	handleApply: Ext.emptyFn,

	handleRefresh: function() {
		var page = this;
		page.fp.down('[itemId=log-grid]').store.load();
	},

	handleSave: function() {
		var page = this,
			url = AS.ARC.util.getApiUrlWithSid(page.apiUrl, {
				"tab": 'log',
				"act": 'download'
			});
		AS.ARC.util.saveLog({
			url: url,
			parentWin: page.fn.app.win
		});
	},

	handleClear: function() {
		var page = this,
			urlOpts = {
				"tab": 'log',
				"act": 'del'
			};

		var doClear = function() {
			page.logGrid.el.mask(_S('COMMON', 'LOADING'));
			/**
			 * Delete the log
			 * @param {String} tab: tab name
			 * @param {String} act: action name
			 */
			AS.ARC.ajax({
				url: AS.ARC.util.getApiUrlWithSid(page.apiUrl, urlOpts),
				method: 'post',
				success: function (json, opts) {
					page.logGrid.store.load();
				},
				failure: function (json, opts) {
					page.logGrid.el.unmask();
					AS.ARC.util.showMsgWindow({}, json, page.fn.app.win, 'warning');
				}
			});
		};

		var win = new AS.ARC.msgWindow({
			title: _S('COMMON', 'CONFIRMATION'),
			width: 400,
			parentWin: page.fn.app.win,
			iconType: 'question',
			asItems: [{
				xtype: 'displayfield',
				value: _S('SYSTEMINFORMATION', 'NOTE_REMOVE_LOG')
			}],
			fbar: [{
				text: _S('COMMON', 'OK'),
				handler: function () {
					win.close();
					doClear();
				},
				scope: this
			}, {
				text: _S('COMMON', 'CANCEL'),
				handler: function () {
					win.close();
				},
				scope: this
			}]
		}).show();
	},

	getLogGrid: function() {
		var page = this,
			urlOpts = {
				"tab": 'log',
				"act": 'get'
			}

		var store = Ext.create('Ext.data.JsonStore', {
			autoDestroy: true,
			pageSize: 30,
			fields: [
				'time', 'type', 'event'
			],
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(page.apiUrl, urlOpts),
				reader: {
					type: 'json',
					root: 'log'
				},
				listeners: {
					exception: function(proxy, response, operation, opts) {
						if (Ext.JSON.decode(response.responseText)) {
							AS.ARC.util.showMsgWindow({}, Ext.JSON.decode(response.responseText), page.fn.app.win);
						}
					}
				}
			},
			listeners: {
				beforeload: function(store, operation) {
					var query = '';
					
					if (page.fp.down('[itemId=search]')) query = page.fp.down('[itemId=search]').getValue();
					Ext.apply(store.proxy.extraParams, { "query": query });

					if (store.isLoading() && store.lastOperation) {
						var requests = Ext.Ajax.requests;
						for (id in requests) {
							if (requests.hasOwnProperty(id) && requests[id].options == store.lastOperation.request) {
								Ext.Ajax.abort(requests[id]);
							}
						}
					}
					store.lastOperation = operation;
					page.logGrid.el.mask(_S('COMMON', 'LOADING'));
				},
				load: function() { page.logGrid.el.unmask(); }
			}
		});

		page.logGrid = Ext.create('Ext.grid.Panel', {
			itemId: 'log-grid',
			height: 373,
			forceFit: true,
			store: store,
			bbar: Ext.create('AS.ARC.pagingToolbar', {
				store: store,
				// doRefresh: function() {}
			}),
			viewConfig: {
				onStoreLoad: function () {
					var container = this.up().body.dom;
					container.scrollTop = 0;
					Ps.update(container);
				},
				loadMask: false,
				style: {overflow: 'auto', overflowX: 'hidden'}
			},
			columns: [{
				text: _S('COMMON', 'TYPE'),
				dataIndex: 'type',
				sortable: false,
				width: 50,
				renderer: function(value, metaData, record, rowIndex, colIndex, store) {
					var result = '';
					if (value == 8) {
						metaData.tdAttr = 'data-qtip=\'' + _S('NOTIFICATION', 'CRITICAL') + '\'';
						result = '<div align="center" class="status-icon-16 critical"></div>';
					} else if (value == 4) {
						metaData.tdAttr = 'data-qtip=\'' + _S('COMMON', 'ERROR') + '\'';
						result = '<div align="center" class="status-icon-16 error"></div>';
					} else if (value == 2) {
						metaData.tdAttr = 'data-qtip=\'' + _S('COMMON', 'WARNING') + '\'';
						result = '<div align="center" class="status-icon-16 warning"></div>';
					} else {
						metaData.tdAttr = 'data-qtip=\'' + _S('COMMON', 'INFORMATION') + '\'';
						result = '<div align="center" class="status-icon-16 info"></div>';
					}
					return result;
				}
			}, {
				text: _S('COMMON', 'TIME'),
				dataIndex: 'time',
				sortable: false,
				width: 160,
				renderer: function(value, metaData, record, rowIndex, colIndex, store) {
					return AS.ARC.util.toSystemTime(AS.ARC.config.dateFormat.DateFormat, AS.ARC.config.dateFormat.TimeFormat, value);
				}
			}, {
				text: _S('SYSTEMINFORMATION', 'EVENT'),
				dataIndex: 'event',
				sortable: false,
				flex: 1,
				renderer: function(value, metaData, record, rowIndex, colIndex, store) {
					metaData.tdAttr = 'data-qtip="' + AS.ARC.util.htmlCharsEncode(value) + '"';
					return AS.ARC.util.htmlCharsEncode(value);
				}
			}]
		});

		return page.logGrid;
	},

	getPanel: function() {
		var page = this;
		var labelWidth = AS.ARC.config.layout.indentWidth + AS.ARC.config.layout.labelWidthSmall;

		page.buttonApply = Ext.create('Ext.button.Button', {
			xtype: 'button',
			text: _S('COMMON', 'APPLY')
		});

		var buttonRefresh = Ext.create('Ext.button.Button', {
			text: _S('COMMON', 'REFRESH'),
			handler: page.handleRefresh,
			scope: this,
			scale: AS.ARC.config.defaultActionButtonSize
		});

		var buttonSave = Ext.create('Ext.button.Button', {
			text: _S('COMMON', 'SAVE'),
			handler: page.handleSave,
			scope: this,
			scale: AS.ARC.config.defaultActionButtonSize
		});

		var buttonClear = Ext.create('Ext.button.Button', {
			text: _S('COMMON', 'CLEAR'),
			handler: page.handleClear,
			scope: this,
			scale: AS.ARC.config.defaultActionButtonSize
		});

		return {
			xtype: 'asFnForm',
			page: page,
			itemId: page.panelItemId,
			title: _S('SYSTEMINFORMATION', 'FN_LOG'),
			border: false,
			cls: 'as-page-panel',
			height: '100%',
			items: [{
				xtype: 'asPanelToolbarTop',
				layout: 'hbox',
				itemId: 'toolbar-top',
				items: [
					buttonRefresh,
					buttonSave,
					buttonClear,
					{
						xtype: 'tbfill'
					}, {
						xtype: 'asSearchField',
						itemId: 'search',
						enableKeyEvents: true,
						checkChangeBuffer: AS.ARC.config.keyBuffer,
						listeners: {
							change: function(field) {
								var grid = page.fp.down('[itemId=log-grid]');
								grid.store.loadPage(1);
							}
						}
					}]
			},
			page.getLogGrid()],
			listeners: {
				resize: function(me) {
					var logGrid = me.down('[itemId=log-grid]');
					logGrid.setHeight(me.body.getHeight() - 36);
					logGrid.setWidth(me.body.getWidth());
				}
			}
		};
	},

	loadData: function() {
		var page = this;
		page.logGrid.store.load();
	}
});

/**
 * @class AS.ARC.apps.radiusserver.log.fn
 * @extends AS.ARC.apps.radiusserver.fn
 * @author JerryJiang 2017-06-23
 */
Ext.define('AS.ARC.apps.radiusserver.log.fn', {
	extend: 'AS.ARC.apps.radiusserver.fn',

	fnTag: 'log',

	init: function(config) {
		// apis
		this.createPanel();
	},

	createPanel: function() {
		var fn = this;

		// create page
		var pageLog = new AS.ARC.apps.radiusserver.log.log({ fn: this });

		this.tabPanel = Ext.create('AS.ARC.fnTabPanel', {
			items: [
				pageLog.getPanel()
			]
		});

		this.tabPanel.enableDataConfirm();

		fn.initMainPanel();
	},

	loadData: function() {
		this.tabPanel.activeTab.page.loadData(true);
	}
});