/* Copyright (c) 2017 Asustor Inc. All rights reserved. */
/**
 * @class AS.ARC.apps.radiusserver.settings.settings
 * @extends AS.ARC.apps.radiusserver.page
 * @author JerryJiang 2017-06-23
 */
Ext.define('AS.ARC.apps.radiusserver.settings.settings', {
	extend: 'AS.ARC.apps.radiusserver.page',

	pageTag: 'settings',
	apiUrl: AS.ARC.util.getUserAppsPath() + 'radiusserver/radiusserver.cgi',

	handleApply: function() {
		var page = this,
			urlOpts = {
				"tab": 'setting',
				"act": 'set'
			}

		var params = page.fp.doDataExchange();
		if( !page.fp.isSettingChange( params ) ){
			page.fp.showSetNotChange();
			return false;
		}

		page.fn.app.maskWin(_S('COMMON', 'APPLYING'));
		AS.ARC.ajax({
			url: AS.ARC.util.getApiUrlWithSid(page.apiUrl, urlOpts),
			method: 'post',
			params: params,
			success: function (json, opts) {
				page.fp.uiChecker.srcData = json;

				page.fp.down('[itemId=port]').setValue(json.port);
				page.fp.down('[itemId=local-user]').setValue(json.enablelocaluser);
				page.fp.showApply();
				page.fn.app.unmaskWin();
			},
			failure: function (json, opts) {
				var errors = {
					5032: _S('ERROR', 'PORT_IS_USED')
				};
				page.fn.app.unmaskWin();
				AS.ARC.util.showMsgWindow(errors, json, page.fn.app.win, 'warning');
			}
		});
	},

	getPanel: function() {
		var page = this;
		var labelWidth = AS.ARC.config.layout.indentWidth + AS.ARC.config.layout.labelWidthSmall;

		page.buttonApply = Ext.create('Ext.button.Button', {
			xtype: 'button',
			text: _S('COMMON', 'APPLY')
		});

		return {
			xtype: 'asFnForm',
			page: page,
			itemId: page.panelItemId,
			title: _S('COMMON', 'SETTING'),
			border: false,
			cls: 'as-page-panel',
			height: '100%',
			fbar: [{
				xtype: 'tbfill'
			},
			page.buttonApply
			],
			items: [{
				xtype: 'fieldset',
				itemId: 'fs-system',
				title: _S('COMMON', 'SETTINGS'),
				defaults: {
					labelWidth: labelWidth,
					msgTarget: AS.ARC.config.msgTarget
				},
				items: [{
					xtype: 'asPort',
					itemId: 'port',
					fieldLabel: _S('RADIUSSERVER', 'AUTHENTICATION_PORT'),
					allowBlank: false,
					value: 1812
				}, {
					xtype: 'displayfield',
					itemId: 'info',
					value: _S('RADIUSSERVER', 'SELECT_SOURCE_TO_AUTHENTICATE') + _S('COMMON', 'COLON'),
				}, {
					xtype: 'checkbox',
					itemId: 'local-user',
					boxLabel: _S('ACCESS_CONTROL', 'FN_LOCAL_USER'),
				}, {
					xtype: 'displayfield',
					cls: 'displayfield note-string',
					value: _S('RADIUSSERVER', 'NOTE_AUTHENTICATION_FORMATS')
				}]
			}],
			doDataExchange: function() {
				var pageData = {};
				Ext.apply(pageData, {
					"enablelocaluser": page.fp.down('[itemId=local-user]').getValue(),
					"port": page.fp.down('[itemId=port]').getValue()
				});
				return pageData;
			}
		};
	},

	loadData: function() {
		var page = this;
		
		AS.ARC.ajax({
			url: AS.ARC.util.getApiUrlWithSid(page.apiUrl, {
				act: 'get',
				tab: 'setting'
			}),
			method: 'get',
			success: function(json, opts) {
				page.fp.uiChecker.srcData = json;

				page.fp.down('[itemId=port]').setValue(json.port);
				page.fp.down('[itemId=local-user]').setValue(json.enablelocaluser);
			},
			failure: function(json, opts) {
				AS.ARC.util.showMsgWindow({}, json, page.fn.app.win, 'warning');
			}
		});
		
	}
});

/**
 * @class AS.ARC.apps.radiusserver.settings.fn
 * @extends AS.ARC.apps.radiusserver.fn
 * @author JerryJiang 2017-06-23
 */
Ext.define('AS.ARC.apps.radiusserver.settings.fn', {
	extend: 'AS.ARC.apps.radiusserver.fn',

	fnTag: 'settings',

	init: function(config) {
		// apis
		this.createPanel();
	},

	createPanel: function() {
		var fn = this;

		// create page
		var pageSettings = new AS.ARC.apps.radiusserver.settings.settings({ fn: this });

		this.tabPanel = Ext.create('AS.ARC.fnTabPanel', {
			items: [
				pageSettings.getPanel()
			]
		});

		this.tabPanel.enableDataConfirm();

		fn.initMainPanel();
	},

	loadData: function() {
		this.tabPanel.activeTab.page.loadData(true);
	}
});